summaryrefslogtreecommitdiffstats
path: root/kdat/TapeFileInfoWidget.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-18 20:34:22 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-18 20:34:22 +0000
commitb09bffed6b43262948018dfb0f11890850ddf7c1 (patch)
tree138696bfcc7ac01070d0e8ecaa1cdf94611a2bd8 /kdat/TapeFileInfoWidget.h
parent6d43944a7130b9d1b4ae3fba37b774aced8612cf (diff)
downloadtdeadmin-b09bffed6b43262948018dfb0f11890850ddf7c1.tar.gz
tdeadmin-b09bffed6b43262948018dfb0f11890850ddf7c1.zip
TQt4 port kdeadmin
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdeadmin@1237416 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kdat/TapeFileInfoWidget.h')
-rw-r--r--kdat/TapeFileInfoWidget.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kdat/TapeFileInfoWidget.h b/kdat/TapeFileInfoWidget.h
index 9098fb0..e6f605e 100644
--- a/kdat/TapeFileInfoWidget.h
+++ b/kdat/TapeFileInfoWidget.h
@@ -30,6 +30,7 @@ class File;
*/
class TapeFileInfoWidget : public TQWidget {
Q_OBJECT
+ TQ_OBJECT
File* _file;
TQLabel* _fileName;
TQLabel* _mtime;
@@ -40,10 +41,10 @@ public:
/**
* Create a new tape file info widget.
*
* @param parent The parent widget.
* @param name The name of this widget.
*/
- TapeFileInfoWidget( TQWidget* parent = 0, const char* name = 0 );
+ TapeFileInfoWidget( TQWidget* tqparent = 0, const char* name = 0 );
/**
* Destroy the tape file info widget.
@@ -40,10 +41,10 @@ public:
* Create a new tape file info widget.
*
- * @param parent The parent widget.
+ * @param tqparent The tqparent widget.
* @param name The name of this widget.
*/